@@ -1,3 +1,5 @@
+import sys
+
 from glQiwiApi.qiwi.clients.maps.client import QiwiMaps
 from glQiwiApi.qiwi.clients.p2p.client import QiwiP2PClient
 from glQiwiApi.qiwi.clients.wallet.client import QiwiWallet
@@ -12,7 +14,15 @@ def default_cache_storage() -> CacheStorage:
     return InMemoryCacheStorage(invalidate_strategy=APIResponsesCacheInvalidationStrategy())
 
 
-__version__ = '2.15'
+if sys.version_info >= (3, 8):
+    from importlib import metadata
+else:
+    import importlib_metadata as metadata
+
+try:
+    __version__ = metadata.version('glQiwiApi')
+except metadata.PackageNotFoundError:
+    __version__ = '99.99.99'
 
 __all__ = (
     # clients
