@@ -8,13 +8,13 @@ from glQiwiApi.qiwi.clients.p2p.types import InvoiceStatus
 
 
 class PayInvoice(QiwiAPIMethod[InvoiceStatus]):
-    url: ClassVar[str] = "https://edge.qiwi.com/checkout-api/api/bill/search"
-    http_method: ClassVar[str] = "POST"
+    url: ClassVar[str] = 'https://edge.qiwi.com/checkout-api/invoice/pay/wallet'
+    http_method: ClassVar[str] = 'POST'
 
     json_payload_schema: ClassVar[Dict[str, Any]] = {
-        "invoice_uid": RuntimeValue(),
-        "currency": RuntimeValue(),
+        'invoice_uid': RuntimeValue(),
+        'currency': RuntimeValue(),
     }
 
-    invoice_uid: str = Field(..., schema_path="invoice_uid")
-    currency: str = Field(..., schema_path="currency")
+    invoice_uid: str = Field(..., schema_path='invoice_uid')
+    currency: str = Field(..., schema_path='currency')
