@@ -6,9 +6,9 @@ from glQiwiApi.qiwi.base import QiwiAPIMethod
 
 
 class SetDefaultBalance(QiwiAPIMethod[Dict[Any, Any]]):
-    http_method: ClassVar[str] = "PATCH"
+    http_method: ClassVar[str] = 'PATCH'
     url: ClassVar[
         str
-    ] = "https://edge.qiwi.com/funding-sources/v2/persons/{phone_number}/accounts/{account_alias}"
+    ] = 'https://edge.qiwi.com/funding-sources/v2/persons/{phone_number}/accounts/{account_alias}'
 
     account_alias: str = Field(..., path_runtime_value=True)
