@@ -11,8 +11,8 @@ from glQiwiApi.utils.currency_util import Currency
 class Interval(Base):
     """object: Interval"""
 
-    date_from: datetime = Field(alias="dateFrom")
-    date_till: datetime = Field(alias="dateTill")
+    date_from: datetime = Field(alias='dateFrom')
+    date_till: datetime = Field(alias='dateTill')
 
 
 class Limit(Base):
@@ -20,16 +20,16 @@ class Limit(Base):
 
     currency: CurrencyModel
     rest: Union[float, int]
-    max_limit: Union[float, int] = Field(alias="max")
+    max_limit: Union[float, int] = Field(alias='max')
     spent: Union[float, int]
     interval: Interval
-    limit_type: str = Field(alias="type")
+    limit_type: str = Field(alias='type')
 
-    @validator("currency", pre=True)
+    @validator('currency', pre=True)
     def currency_validate(cls, v):  # type: ignore
         if not isinstance(v, str):
             raise ValueError()
         return Currency.get(v)
 
 
-__all__ = ["Limit"]
+__all__ = ['Limit']
