@@ -1,9 +1,7 @@
-from __future__ import annotations
-
 import functools
 from typing import Callable, TypeVar
 
-T = TypeVar("T")
+T = TypeVar('T')
 
 
 def lru_cache(maxsize: int = 128, typed: bool = False) -> Callable[[T], T]:
