@@ -1,3 +1,3 @@
 from .client import YooMoneyAPI
 
-__all__ = ("YooMoneyAPI",)
+__all__ = ('YooMoneyAPI',)
